@@ -791,18 +791,17 @@ class InputMedia(TgObject):
 class InputMediaPhoto(InputMedia):
     """ https://core.telegram.org/bots/api#inputmediaphoto """
 
-    type: str
     media: str
     caption: str = None
     parse_mode: str = None
     caption_entities: list[MessageEntity] = None
+    type: str = 'photo'
 
 
 @dataclass
 class InputMediaVideo(InputMedia):
     """ https://core.telegram.org/bots/api#inputmediavideo """
 
-    type: str
     media: str
     thumb: InputFile | str = None
     caption: str = None
@@ -812,13 +811,13 @@ class InputMediaVideo(InputMedia):
     height: int = None
     duration: int = None
     supports_streaming: bool = None
+    type: str = 'video'
 
 
 @dataclass
 class InputMediaAnimation(InputMedia):
     """ https://core.telegram.org/bots/api#inputmediaanimation """
 
-    type: str
     media: str
     thumb: InputFile | str = None
     caption: str = None
@@ -827,13 +826,13 @@ class InputMediaAnimation(InputMedia):
     width: int = None
     height: int = None
     duration: int = None
+    type: str = 'animation'
 
 
 @dataclass
 class InputMediaAudio(InputMedia):
     """ https://core.telegram.org/bots/api#inputmediaaudio """
 
-    type: str
     media: str
     thumb: InputFile | str = None
     caption: str = None
@@ -842,19 +841,20 @@ class InputMediaAudio(InputMedia):
     duration: int = None
     performer: str = None
     title: str = None
+    type: str = 'audio'
 
 
 @dataclass
 class InputMediaDocument(InputMedia):
     """ https://core.telegram.org/bots/api#inputmediadocument """
 
-    type: str
     media: str
     thumb: InputFile | str = None
     caption: str = None
     parse_mode: str = None
     caption_entities: list[MessageEntity] = None
     disable_content_type_detection: bool = None
+    type: str = 'document'
 
 
 @dataclass
