@@ -5,7 +5,7 @@ from ..objects.tg_methods import SendMediaGroup
 
 
 def send_media_group(
-        media: list[InputMediaAudio, InputMediaDocument, InputMediaPhoto, InputMediaVideo],
+        media: list[InputMediaAudio | InputMediaDocument | InputMediaPhoto | InputMediaVideo],
 
         chat_id: int | str = None,
         disable_notification: bool = None,
@@ -14,9 +14,14 @@ def send_media_group(
         reply_to_message_id: int = None,
         allow_sending_without_reply: bool = None,
 ) -> list[Message]:
+    _locals = locals()
+
+    for m in media:
+        m.parse_mode = m.parse_mode or ctx.parse_mode
+
     return request(
         SendMediaGroup,
-        locals(),
+        _locals,
         chat_id=ctx.chat_id,
         disable_notification=ctx.disable_notification,
         protect_content=ctx.protect_content,
